@@ -8,7 +8,7 @@ __author__ = "Michael Shobitan"
 __copyright__ = "Copyright 2019, BTCS Platform Engineering"
 __credits__ = ["Michael Shobitan"]
 __license__ = "PFE"
-__version__ = "0.2.0"
+__version__ = "0.2.2"
 __maintainer__ = "Michael Shobitan"
 __email__ = "michael.shobitan@pfizer.com"
 __status__ = "Development"
@@ -74,6 +74,10 @@ def jsonPP(json_content):
     response = json.dumps(json_content, indent=4)
     return response
 
+def ppJSON(json_content):
+    response = json.dumps(json_content, indent=4, sort_keys=True, default=str)
+    return response
+
 def cd(cd_dir):
     os.chdir(cd_dir)
 
@@ -179,28 +183,39 @@ def describe_stack(cloudformation, cluster):
     return response
 
 def describe_stack_dynamically(cloudformation, cluster):
-    try:
-        # cloudformation = boto3.client('cloudformation')
-        # stack_name = "%s-eks-worker-nodes" % (args.environment)
-        print('Hi')
-        response = cloudformation.describe_stacks()
-        print(response)
+    response = cloudformation.describe_stacks()
+    responseMore = cloudformation.describe_stacks(NextToken=response['NextToken'])
+    allResponses = [response, responseMore]
 
-        clusterStackNames = []
-        stacksINFO = []
-        for counter in xrange(len(response['Stacks'])):
-            # print(len(response['Stacks']))
-            stackName = response['Stacks'][counter]['StackName']
-            if(args.environment in stackName):
-                clusterStackNames.append(stackName)
-                # print(response['Stacks'][counter])
-                stacksINFO.append(response['Stacks'][counter])
-                # print(json.dumps(response['Stacks'][counter], indent=4, sort_keys=True, default=str))
+    clusterStackNames = []
+    stacksINFO = []
+    def aggregateAllStackInfo(thisResponse):
+        if(sys.version_info > (3, 0)):
+            for counter in range(len(response['Stacks'])): # Python3.6
+                stackName = response['Stacks'][counter]['StackName']
+                if(cluster in stackName):
+                    clusterStackNames.append(stackName)
+                    # print(response['Stacks'][counter])
+                    stacksINFO.append(response['Stacks'][counter])
+                    # print(json.dumps(response['Stacks'][counter], indent=4, sort_keys=True, default=str))
+        else:
+            for counter in xrange(len(response['Stacks'])): # Python2.7
+                stackName = response['Stacks'][counter]['StackName']
+                if(cluster in stackName):
+                    clusterStackNames.append(stackName)
+                    # print(response['Stacks'][counter])
+                    stacksINFO.append(response['Stacks'][counter])
+                    # print(json.dumps(response['Stacks'][counter], indent=4, sort_keys=True, default=str))
 
-        # print(clusterStackNames)
-        return stacksINFO
-    except:
-        pass
+        return clusterStackNames, stacksINFO
+
+    for thisResponse in allResponses:
+        allStackData = aggregateAllStackInfo(thisResponse)
+    
+    clusterStackNames.append(allStackData[0])
+    stacksINFO.append(allStackData[1])
+
+    return {'clusterStackNames': clusterStackNames, 'stacksINFO': stacksINFO}
 
 def cahc(cluster):
     eks = eks()
